@@ -8,15 +8,15 @@
 from reahl.tofu import test
 from reahl.web_dev.fixtures import WebFixture
 from reahl.webdev.tools import XPath
-from reahl.doc.examples.tutorial.pager.pager import AddressBookApp
+from reahl.doc.examples.tutorial.pager.pager import AddressBookUI
 
 
 class PagingFixture(WebFixture):
     def new_browser(self):
         return self.driver_browser
         
-    def new_webapp(self):
-        return super(PagingFixture, self).new_webapp(site_root=AddressBookApp, enable_js=True)
+    def new_wsgi_app(self):
+        return super(PagingFixture, self).new_wsgi_app(site_root=AddressBookUI, enable_js=True)
 
     def is_email_listed(self, email):
         return self.browser.is_element_present(XPath.paragraph_containing(email))
@@ -26,7 +26,7 @@ class PagingFixture(WebFixture):
 def paging(fixture):
     """Clicking on a different page in the pager changes the addresses listed without triggering a page load."""
 
-    fixture.reahl_server.set_app(fixture.webapp)
+    fixture.reahl_server.set_app(fixture.wsgi_app)
     browser = fixture.browser
 
     browser.open(u'/')
